<?php
/**
 * Created by PhpStorm.
 * User: loyaltysolutions
 * Date: 20/06/2019
 * Time: 2:19 AM
 */

namespace App\Http\Controllers;

use App\ExperiencesStore;
use App\Products;
use App\Traits\RatesTrait;
use Illuminate\Http\Request;

use Illuminate\Support\Facades\Schema;
use Illuminate\Support\Facades\Validator;

class ProductsController extends Controller
{

    use RatesTrait;
    public function save_products($array){

        $save_data = Products::insert($array);

        if(!$save_data){
            return ['status' => '0', 'message' => 'failed'];

        } else {
            return ['status' => '1', 'message' => 'success'];
        }

    }

    public function get_experiences_by_city(Request $request){
        $valid = Validator::make($request->all(), [
            'city_id' => 'required'
        ]);

        if($valid->fails()){
            return response()->json([
                'data' => [], 'message' => 'city_id required', 'status' => '400'], 400);
        }

        $page = $request->has('page') ? $request->page : 0;
        $limit = $request->has('limit') ? $request->limit : 30;
        $new_page = ($page - 1) * $limit;
        $total = Products::where('city_id', $request['city_id'])->count();
        $data = Products::where('city_id', $request['city_id'])->where('status', 1)->offset($new_page)->limit($limit)->get();
        if(count($data)) {
            return response()->json([
                'data' => ['results' => $data, 'total' =>$total], 'message' => 'Products loaded', 'status' => '200'], 200);
        }
        return response()->json([
            'data' => [], 'message' => 'No data for selected city', 'status' => '400'], 400);
    }

    public function store_popular_cities(Request $request){
        $valid = Validator::make($request->all(), [
            'city_id' => 'required|bail',
            'image' => 'required|bail'
        ]);

        if($valid->fails()){
            return response()->json([
                'data' => [], 'message' => $valid->errors()->first(), 'status' => '400'], 400);
        }

        try{
            \App\PopularCities::updateOrCreate($request->all());
            return response()->json([
                'data' => [], 'message' => 'Successful', 'status' => '200'], 200);
        }catch (\Exception $e){
            return response()->json([
                'data' => [], 'message' => $e->getMessage(), 'status' => '400'], 400);
        }
    }

    public function delete_popular_cities(Request $request){
        $valid = Validator::make($request->all(), [
            'id' => 'required'
        ]);

        if($valid->fails()){
            return response()->json([
                'data' => [], 'message' => $valid->errors()->first(), 'status' => '400'], 400);
        }

        try{
            \App\PopularCities::destroy($request->id);
            return response()->json([
                'data' => [], 'message' => 'Successful', 'status' => '200'], 200);
        }catch (\Exception $e){
            return response()->json([
                'data' => [], 'message' => $e->getMessage(), 'status' => '400'], 400);
        }
    }

    public function update_popular_cities(Request $request){
        $valid = Validator::make($request->all(), [
            'id' => 'required',
            'city_id' => 'required',
            'image' => 'required',
        ]);

        if($valid->fails()){
            return response()->json([
                'data' => [], 'message' => $valid->errors()->first(), 'status' => '400'], 400);
        }

        try{
            \App\PopularCities::where('id', $request->id)->update(
                [
                    'city_id' => $request->city_id,
                    'image' => $request->image,
                ]
            );
            return response()->json([
                'data' => [], 'message' => 'Successful', 'status' => '200'], 200);
        }catch (\Exception $e){
            return response()->json([
                'data' => [], 'message' => $e->getMessage(), 'status' => '400'], 400);
        }
    }

    public function get_popular_cities(){
        $popular_cities = \App\PopularCities::join('city', 'popular_cities.city_id', 'city.id')
            ->join('countries', 'city.country_id', 'countries.id')
            ->select('city.name as city_name', 'countries.name as country_name', 'city_id', 'country_id', 'image' )
            ->get();
        return response()->json([
            'data' => $popular_cities, 'message' => 'Successful', 'status' => '200'], 200);
    }


    public function update_product_rates (){
        $use_rates = new RatesController();
        $changed_rates = $use_rates->get_changed_rates();

        if (is_array($changed_rates)){

            $country_array = array();
            $country_array = array_column($changed_rates, 'country');
            //dd($changed_rates);
            if(!empty($changed_rates)){

                if(in_array('NGN', $country_array)){
                    $products= Products::all();

                } else {
                    $products = Products::whereIn('currency_base', $country_array)->get();
                }
                //dd($products);

                $rates_array = $use_rates->ListRates();
                if ($rates_array) {
                    $x = 0;
                    foreach ($products as $items) {

                        $naira = $use_rates->convert_to_naira($rates_array, $items->currency_base, $items->price);
                        //dd($items->id);

                        $update_products = Products::where('id', $items->id)->update(['update_status' => 0, 'naira_price' => $naira] );
//                        dd($update_products);
//                        dd($naira);
                        $x++;
                    }

                    $update_rates_status = $use_rates->change_update_status_used();

                    if ($update_rates_status['status'] = 1){

                        return ['status' => '1', 'message' => 'success', 'count'=>$x];

                    } else {

                        return "Failed to update rates status";
                    }


                } else {

                    return "Unable to load rates";
                }
            } else {

                return "Null empty rates";
            }

        } else {

            return "No changed Rates";
        }


    }

    public function exist_disable_products(){

        $archive_products = Products::whereNotIn('guid', function ($query) {
            $query->select('guid')
                ->from('experiencesStore');
        })->get();

        $disable_data = $archive_products->toArray();

        if(!empty($disable_data)){
            $x=0;
            foreach ($disable_data as $items) {

                $x++;
                //dd($items);

                $update_products = Products::where('id', $items['id'])->update(['update_status' => 0, 'status' => 0 , 'naira_price' => 0] );
//                        dd($update_products);
//                        dd($naira);
            }

            return "Disable check complete (".$x.")";
        } else {

            return "No data to disable";
        }


        //return $disable_data;

    }

    public function update_product_prices(){

        $changed_products = ExperiencesStore::whereIn('guid', function ($query) {
            $query->select('guid')
                ->from('products')
                ->whereRaw('products.price != experiencesstore.price');
        })->get();

        //dd($changed_products);
        $update_data = $changed_products->toArray();

        if(!empty($update_data)){
            $rates = new RatesController();
            $get_rates = $rates->ListRates();


            $x=0;
            foreach ($update_data as $items) {

                $x++;
                $ngn_amount = $rates->convert_to_naira($get_rates, $items['currency_base'], $items['price']);
                //dd($ngn_amount);

                $update_products = Products::where('guid', $items['guid'])->update(['update_status' => 0, 'status' => 1 , 'price'=>$items['price'],'naira_price' => $ngn_amount] );
//                        dd($update_products);
//                        dd($naira);
            }

            return "Update check complete (".$x.")";
        } else {

            return "No data to update";
        }
    }
}